@@ -61,8 +61,8 @@ anjuta_plugin_manager_error_get_type (void)
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { ANJUTA_PLUGIN_MANAGER_ERROR_INVALID_TYPE, "ANJUTA_PLUGIN_MANAGER_ERROR_INVALID_TYPE", "invalid-type" },
-      { ANJUTA_PLUGIN_MANAGER_ERROR_UNKNOWN, "ANJUTA_PLUGIN_MANAGER_ERROR_UNKNOWN", "unknown" },
+      { ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY, "ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY", "missing-factory" },
+      { ANJUTA_PLUGIN_MANAGER_ERROR_UNKNOWN, "ANJUTA_PLUGIN_MANAGER_ERROR_UNKNOWN", "error-unknown" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static (g_intern_static_string ("AnjutaPluginManagerError"), values);
@@ -96,10 +96,11 @@ anjuta_property_object_type_get_type (void)
       { ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE, "ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE", "toggle" },
       { ANJUTA_PROPERTY_OBJECT_TYPE_SPIN, "ANJUTA_PROPERTY_OBJECT_TYPE_SPIN", "spin" },
       { ANJUTA_PROPERTY_OBJECT_TYPE_ENTRY, "ANJUTA_PROPERTY_OBJECT_TYPE_ENTRY", "entry" },
-      { ANJUTA_PROPERTY_OBJECT_TYPE_MENU, "ANJUTA_PROPERTY_OBJECT_TYPE_MENU", "menu" },
+      { ANJUTA_PROPERTY_OBJECT_TYPE_COMBO, "ANJUTA_PROPERTY_OBJECT_TYPE_COMBO", "combo" },
       { ANJUTA_PROPERTY_OBJECT_TYPE_TEXT, "ANJUTA_PROPERTY_OBJECT_TYPE_TEXT", "text" },
       { ANJUTA_PROPERTY_OBJECT_TYPE_COLOR, "ANJUTA_PROPERTY_OBJECT_TYPE_COLOR", "color" },
       { ANJUTA_PROPERTY_OBJECT_TYPE_FONT, "ANJUTA_PROPERTY_OBJECT_TYPE_FONT", "font" },
+      { ANJUTA_PROPERTY_OBJECT_TYPE_FILE, "ANJUTA_PROPERTY_OBJECT_TYPE_FILE", "file" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static (g_intern_static_string ("AnjutaPropertyObjectType"), values);
@@ -188,6 +189,25 @@ anjuta_serializer_mode_get_type (void)
   return etype;
 }
 
+/* enumerations from "anjuta-vcs-status-tree-view.h" */
+GType
+anjuta_vcs_status_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { ANJUTA_VCS_STATUS_MODIFIED, "ANJUTA_VCS_STATUS_MODIFIED", "modified" },
+      { ANJUTA_VCS_STATUS_ADDED, "ANJUTA_VCS_STATUS_ADDED", "added" },
+      { ANJUTA_VCS_STATUS_DELETED, "ANJUTA_VCS_STATUS_DELETED", "deleted" },
+      { ANJUTA_VCS_STATUS_CONFLICTED, "ANJUTA_VCS_STATUS_CONFLICTED", "conflicted" },
+      { ANJUTA_VCS_STATUS_MISSING, "ANJUTA_VCS_STATUS_MISSING", "missing" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static (g_intern_static_string ("AnjutaVcsStatus"), values);
+  }
+  return etype;
+}
+
 #define __ANJUTA_ENUM_TYPES_C__
 
 /* Generated data ends here */
