@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 /**
@@ -37,9 +37,9 @@
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-plugin-handle.h>
 #include <libanjuta/anjuta-plugin.h>
-#include <libanjuta/anjuta-glue-factory.h>
-#include <libanjuta/anjuta-glue-c.h>
-#include <libanjuta/interfaces/ianjuta-plugin-loader.h>
+#include <libanjuta/anjuta-c-plugin-factory.h>
+#include <libanjuta/interfaces/ianjuta-plugin-factory.h>
+
 
 enum
 {
@@ -106,8 +106,7 @@ enum {
 
 /* Plugin class types */
 
-static GHashTable  *plugin_types = NULL;
-static AnjutaGlueFactory *anjuta_glue_factory = NULL;
+static AnjutaCPluginFactory *anjuta_plugin_factory = NULL;
 
 static GObjectClass* parent_class = NULL;
 static guint plugin_manager_signals[LAST_SIGNAL] = { 0 };
@@ -116,8 +115,8 @@ static GHashTable* plugin_set_update (AnjutaPluginManager *plugin_manager,
 									  AnjutaPluginHandle* selected_plugin,
 									  gboolean load);
 
-static GType get_plugin_loader_type (AnjutaPluginManager *plugin_manager,
-								  const gchar *language);
+static IAnjutaPluginFactory* get_plugin_factory (AnjutaPluginManager *plugin_manager,
+								  const gchar *language, GError **error);
 
 GQuark 
 anjuta_plugin_manager_error_quark (void)
@@ -488,8 +487,11 @@ on_plugin_activated (AnjutaPlugin *plugin_object, AnjutaPluginHandle *plugin)
 	
 	/* FIXME: Pass plugin_manager directly in signal arguments */
 	plugin_manager = anjuta_shell_get_plugin_manager (plugin_object->shell, NULL);
-	priv = plugin_manager->priv;
 	
+	g_return_if_fail(plugin_manager != NULL);
+	
+	priv = plugin_manager->priv;
+
 	g_hash_table_insert (priv->activated_plugins, plugin,
 						 G_OBJECT (plugin_object));
 	if (g_hash_table_lookup (priv->plugins_cache, plugin))
@@ -508,6 +510,9 @@ on_plugin_deactivated (AnjutaPlugin *plugin_object, AnjutaPluginHandle *plugin)
 	
 	/* FIXME: Pass plugin_manager directly in signal arguments */
 	plugin_manager = anjuta_shell_get_plugin_manager (plugin_object->shell, NULL);
+	
+	g_return_if_fail (plugin_manager != NULL);
+	
 	priv = plugin_manager->priv;
 	
 	g_hash_table_insert (priv->plugins_cache, plugin, G_OBJECT (plugin_object));
@@ -518,72 +523,39 @@ on_plugin_deactivated (AnjutaPlugin *plugin_object, AnjutaPluginHandle *plugin)
 						   plugin_object);
 }
 
-static GObject *
+static AnjutaPlugin*
 activate_plugin (AnjutaPluginManager *plugin_manager,
-				 AnjutaPluginHandle *plugin, GError **error)
+				 AnjutaPluginHandle *handle, GError **error)
 {
 	AnjutaPluginManagerPriv *priv;
-	GType type;
-	GType glue_type;
-	GObject *ret;
+	IAnjutaPluginFactory* factory;
+	AnjutaPlugin *plugin;
 	const gchar *plugin_id;
 	const gchar *language;
 	gboolean resident;
 	
 	priv = plugin_manager->priv;
 	
-	if (!plugin_types)
+	plugin_id = anjuta_plugin_handle_get_id (handle);
+	
+	resident = anjuta_plugin_handle_get_resident (handle);
+	language = anjuta_plugin_handle_get_language (handle);
+	
+	factory = get_plugin_factory (plugin_manager, language, error);
+	if (factory == NULL) return NULL;
+	
+	plugin = ianjuta_plugin_factory_new_plugin (factory, handle, ANJUTA_SHELL (priv->shell), error);
+	
+	if (plugin == NULL)
 	{
-		plugin_types = g_hash_table_new (g_str_hash, g_str_equal);
-	}
-	
-	plugin_id = anjuta_plugin_handle_get_id (plugin);
-	
-	resident = anjuta_plugin_handle_get_resident (plugin);
-	language = anjuta_plugin_handle_get_language (plugin);
-	
-	glue_type = get_plugin_loader_type (plugin_manager, language);
-	if (glue_type == G_TYPE_INVALID)
-	{
-		g_set_error (error, ANJUTA_PLUGIN_MANAGER_ERROR,
-					 ANJUTA_PLUGIN_MANAGER_ERROR_INVALID_TYPE,
-					 _("Invalid plugin: %s"), plugin_id);
-		
 		return NULL;
 	}
+	g_signal_connect (plugin, "activated",
+					  G_CALLBACK (on_plugin_activated), handle);
+	g_signal_connect (plugin, "deactivated",
+					  G_CALLBACK (on_plugin_deactivated), handle);
 	
-	type = GPOINTER_TO_UINT (g_hash_table_lookup (plugin_types, plugin_id));
-	
-	if (!type)
-	{
-		char **pieces;
-		/* DEBUG_PRINT ("Loading: %s", plugin_id); */
-		pieces = g_strsplit (plugin_id, ":", -1);
-		type = anjuta_glue_factory_get_object_type (anjuta_glue_factory,
-										     pieces[0], pieces[1],
-										     resident, glue_type);
-		if (type != G_TYPE_INVALID)
-			g_hash_table_insert (plugin_types, g_strdup (plugin_id),
-								 GUINT_TO_POINTER (type));
-		g_strfreev (pieces);
-	}
-	
-	if (type == G_TYPE_INVALID)
-	{
-		g_set_error (error, ANJUTA_PLUGIN_MANAGER_ERROR,
-					 ANJUTA_PLUGIN_MANAGER_ERROR_INVALID_TYPE,
-					 _("Invalid plugin: %s"), plugin_id);
-		ret = NULL;
-	}
-	else
-	{
-		ret = g_object_new (type, "shell", priv->shell, NULL);
-		g_signal_connect (ret, "activated",
-						  G_CALLBACK (on_plugin_activated), plugin);
-		g_signal_connect (ret, "deactivated",
-						  G_CALLBACK (on_plugin_deactivated), plugin);
-	}
-	return ret;
+	return plugin;
 }
 
 static gboolean
@@ -772,7 +744,7 @@ plugin_set_update (AnjutaPluginManager *plugin_manager,
 			AnjutaPluginHandle *plugin = l->data;
 			if (should_load (priv->activated_plugins, selected_plugin, plugin))
 			{
-				GObject *plugin_obj;
+				AnjutaPlugin *plugin_obj;
 				GError *error = NULL;
 				plugin_obj = g_hash_table_lookup (priv->plugins_cache, plugin);
 				if (!plugin_obj)
@@ -790,18 +762,12 @@ plugin_set_update (AnjutaPluginManager *plugin_manager,
 					if (error)
 					{
 						gchar* message = g_strdup_printf (_("Could not load %s\n"
-							"This usually means that your installation is corrupted.\n"
-							"The error message leading to this was:\n%s"), 
+							"This usually means that your installation is corrupted. The "
+							"error message leading to this was:\n%s"), 
 														  anjuta_plugin_handle_get_name (selected_plugin),
 														  error->message);
-						GtkWidget* dialog = gtk_message_dialog_new (NULL, 
-												GTK_DIALOG_MODAL,
-												GTK_MESSAGE_ERROR,
-												GTK_BUTTONS_OK,
-												message);
-						gtk_dialog_run (GTK_DIALOG (dialog));
-						gtk_widget_destroy (dialog);
-						
+						anjuta_util_dialog_error (GTK_WINDOW(plugin_manager->priv->shell),
+												  message);
 						g_error_free (error);
 						g_free(message);
 					}
@@ -1130,28 +1096,18 @@ on_forget_plugin_sel_changed (GtkTreeSelection *selection,
 		gtk_widget_set_sensitive (button, FALSE);
 }
 
-static GtkWidget *
-create_plugin_page (AnjutaPluginManager *plugin_manager)
+GtkWidget *
+anjuta_plugin_manager_get_plugins_page (AnjutaPluginManager *plugin_manager)
 {
-	GtkWidget *notebook;
-	GtkWidget *page_label;
 	GtkWidget *vbox;
 	GtkWidget *checkbutton;
 	GtkWidget *tree;
 	GtkWidget *scrolled;
 	GtkListStore *store;
-	GtkWidget *hbox;
-	GtkWidget *display_label;
-	GtkWidget *forget_button;
-	GtkTreeSelection *selection;
-	
-	notebook = gtk_notebook_new ();
 	
 	/* Plugins page */
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 10);
-	page_label = gtk_label_new (_("Plugins"));
-	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, page_label);
 	
 	checkbutton = gtk_check_button_new_with_label (_("Only show user activatable plugins"));
 	gtk_container_set_border_width (GTK_CONTAINER (checkbutton), 10);
@@ -1180,7 +1136,22 @@ create_plugin_page (AnjutaPluginManager *plugin_manager)
 	g_signal_connect (G_OBJECT (checkbutton), "toggled",
 					  G_CALLBACK (on_show_all_plugins_toggled),
 					  store);
-	
+	gtk_widget_show_all (vbox);
+	return vbox;
+}
+
+GtkWidget *
+anjuta_plugin_manager_get_remembered_plugins_page (AnjutaPluginManager *plugin_manager)
+{
+	GtkWidget *vbox;
+	GtkWidget *tree;
+	GtkWidget *scrolled;
+	GtkListStore *store;
+	GtkWidget *hbox;
+	GtkWidget *display_label;
+	GtkWidget *forget_button;
+	GtkTreeSelection *selection;
+
 	/* Remembered plugin */
 	vbox = gtk_vbox_new (FALSE, 10);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 10);
@@ -1193,9 +1164,6 @@ create_plugin_page (AnjutaPluginManager *plugin_manager)
 	gtk_label_set_line_wrap (GTK_LABEL (display_label), TRUE);
 	gtk_box_pack_start (GTK_BOX (vbox), display_label, FALSE, FALSE, 0);
 
-	page_label = gtk_label_new (_("Preferred plugins"));
-	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, page_label);
-	
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
 									     GTK_SHADOW_IN);
@@ -1225,13 +1193,8 @@ create_plugin_page (AnjutaPluginManager *plugin_manager)
 	g_signal_connect (selection, "changed",
 					  G_CALLBACK (on_forget_plugin_sel_changed),
 					  forget_button);
-	
-	/* For cursor status */
-	
-	gtk_widget_show_all (notebook);
-	if (plugin_manager->priv->status)
-		anjuta_status_add_widget (plugin_manager->priv->status, notebook);
-	return notebook;
+	gtk_widget_show_all (vbox);
+	return vbox;
 }
 
 static GList *
@@ -1249,23 +1212,24 @@ property_to_list (const char *value)
 	return l;
 }
 
-static GType
-get_plugin_loader_type (AnjutaPluginManager *plugin_manager,
-								  const gchar *language)
+static IAnjutaPluginFactory*
+get_plugin_factory (AnjutaPluginManager *plugin_manager,
+								 	const gchar *language,
+									GError **error)
 {
 	AnjutaPluginManagerPriv *priv;
 	AnjutaPluginHandle *plugin;
 	GList *loader_plugins, *node;
 	GList *valid_plugins;
 	GObject *obj = NULL;
-	
+
 	g_return_val_if_fail (ANJUTA_IS_PLUGIN_MANAGER (plugin_manager), G_TYPE_INVALID);
 
 	
 	if ((language == NULL) || (g_ascii_strcasecmp (language, "C") == 0))
 	{
 		/* Support of C plugin is built-in */
-		return ANJUTA_GLUE_TYPE_C_PLUGIN;
+		return IANJUTA_PLUGIN_FACTORY (anjuta_plugin_factory);
 	}
 	
 	priv = plugin_manager->priv;
@@ -1361,18 +1325,15 @@ get_plugin_loader_type (AnjutaPluginManager *plugin_manager,
 
 	if (obj != NULL)
 	{
-		/* Get type of glue object */
-		IAnjutaPluginLoader *loader;
-			
-		loader = IANJUTA_PLUGIN_LOADER (ANJUTA_PLUGIN(obj));
-		
-		return ianjuta_plugin_loader_glue_plugin_get_type (loader, NULL);
+		return IANJUTA_PLUGIN_FACTORY (obj);
 	}
 	
 	/* No plugin implementing this interface found */
-	g_warning ("No plugin found to load a %s plugin.", language);
+	g_set_error (error, ANJUTA_PLUGIN_MANAGER_ERROR,
+					 ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY,
+					 _("No plugin able to load other plugins in %s"), language);
 	
-	return G_TYPE_INVALID;
+	return NULL;
 }
 
 /**
@@ -1508,14 +1469,34 @@ on_activated_plugins_foreach (gpointer key, gpointer data, gpointer user_data)
 						anjuta_plugin_handle_get_description (plugin));
 }
 
+static void
+on_activated_plugin_objects_foreach (gpointer key, gpointer data, gpointer user_data)
+{
+	GList **active_plugins = (GList **)user_data;
+	*active_plugins = g_list_prepend (*active_plugins,
+						data);
+}
+
 GList*
 anjuta_plugin_manager_get_active_plugins (AnjutaPluginManager *plugin_manager)
+{
+	GList *active_plugins = NULL;
+
+	g_return_val_if_fail (ANJUTA_IS_PLUGIN_MANAGER (plugin_manager), NULL);
+	g_hash_table_foreach (plugin_manager->priv->activated_plugins,
+						  on_activated_plugins_foreach,
+						  &active_plugins);
+	return g_list_reverse (active_plugins);
+}
+
+GList* 
+anjuta_plugin_manager_get_active_plugin_objects (AnjutaPluginManager *plugin_manager)
 {
 	GList *active_plugins = NULL;
 	
 	g_return_val_if_fail (ANJUTA_IS_PLUGIN_MANAGER (plugin_manager), NULL);
 	g_hash_table_foreach (plugin_manager->priv->activated_plugins,
-						  on_activated_plugins_foreach,
+						  on_activated_plugin_objects_foreach,
 						  &active_plugins);
 	return g_list_reverse (active_plugins);
 }
@@ -1591,12 +1572,6 @@ anjuta_plugin_manager_unload_plugin (AnjutaPluginManager *plugin_manager,
 	return FALSE;
 }
 
-GtkWidget *
-anjuta_plugin_manager_get_dialog (AnjutaPluginManager *plugin_manager)
-{
-	return create_plugin_page (plugin_manager);
-}
-
 GList*
 anjuta_plugin_manager_query (AnjutaPluginManager *plugin_manager,
 							 const gchar *section_name,
@@ -1902,17 +1877,17 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 		{
 			g_warning ("Plugin does not define Icon attribute");
 		}
-		if (!anjuta_plugin_description_get_string (desc,
-												  "Anjuta Plugin",
-												  "Name",
-												  &plugin_name))
+		if (!anjuta_plugin_description_get_locale_string (desc,
+														  "Anjuta Plugin",
+														  "Name",
+														  &plugin_name))
 		{
 			g_warning ("Plugin does not define Name attribute");
 		}
-		if (!anjuta_plugin_description_get_string (desc,
-												  "Anjuta Plugin",
-												  "Description",
-												  &plugin_desc))
+		if (!anjuta_plugin_description_get_locale_string (desc,
+														  "Anjuta Plugin",
+														  "Description",
+														  &plugin_desc))
 		{
 			g_warning ("Plugin does not define Description attribute");
 		}
@@ -2099,15 +2074,10 @@ anjuta_plugin_manager_finalize (GObject *object)
 		priv->plugin_dirs = NULL;
 	}
 #if 0
-	if (plugin_types)
+	if (anjuta_c_plugin_factory)
 	{
-		g_hash_table_destroy (plugin_types);
-		plugin_types = NULL;
-	}
-	if (anjuta_glue_factory)
-	{
-		g_object_unref (anjuta_glue_factory);
-		anjuta_glue_factory = NULL;
+		g_object_unref (anjuta_c_plugin_factory);
+		anjuta_c_plugin_factory = NULL;
 	}
 #endif
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -2300,9 +2270,9 @@ anjuta_plugin_manager_new (GObject *shell, AnjutaStatus *status,
 								   "shell", shell, "status", status, NULL);
 	plugin_manager = ANJUTA_PLUGIN_MANAGER (manager_object);
 	
-	if (anjuta_glue_factory == NULL)
+	if (anjuta_plugin_factory == NULL)
 	{
-		anjuta_glue_factory = anjuta_glue_factory_new ();
+		anjuta_plugin_factory = anjuta_c_plugin_factory_new ();
 	}
 	
 	gnome2_path = g_getenv ("GNOME2_PATH");
@@ -2312,7 +2282,6 @@ anjuta_plugin_manager_new (GObject *shell, AnjutaStatus *status,
 		for (p = pathv; *p != NULL; p++) {
 			char *path = g_strdup (*p);
 			plugin_dirs = g_list_prepend (plugin_dirs, path);
-			anjuta_glue_factory_add_path (anjuta_glue_factory, path);
 		}
 		g_strfreev (pathv);
 	}
@@ -2323,7 +2292,6 @@ anjuta_plugin_manager_new (GObject *shell, AnjutaStatus *status,
 			continue;
 		char *path = g_strdup (node->data);
 		plugin_dirs = g_list_prepend (plugin_dirs, path);
-		anjuta_glue_factory_add_path (anjuta_glue_factory, path);
 		node = g_list_next (node);
 	}
 	plugin_dirs = g_list_reverse (plugin_dirs);
@@ -2336,6 +2304,8 @@ anjuta_plugin_manager_new (GObject *shell, AnjutaStatus *status,
 		node = g_list_next (node);
 	}
 	resolve_dependencies (plugin_manager, &cycles);
+	g_list_foreach(plugin_dirs, (GFunc) g_free, NULL);
+	g_list_free(plugin_dirs);
 	return plugin_manager;
 }
 
@@ -2372,13 +2342,15 @@ anjuta_plugin_manager_activate_plugins (AnjutaPluginManager *plugin_manager,
 												  "Icon",
 											  &icon_filename))
 		{
-			gchar *title, *description;
-			anjuta_plugin_description_get_string (d, "Anjuta Plugin",
-												  "Name",
-												  &title);
-			anjuta_plugin_description_get_string (d, "Anjuta Plugin",
-												  "Description",
-												  &description);
+			gchar *title /*, *description */;
+			anjuta_plugin_description_get_locale_string (d, "Anjuta Plugin",
+														 "Name",
+														 &title);
+			/*
+			anjuta_plugin_description_get_locale_string (d, "Anjuta Plugin",
+														 "Description",
+														 &description);
+			*/
 			icon_path = g_strconcat (PACKAGE_PIXMAPS_DIR"/",
 									 icon_filename, NULL);
 			/* DEBUG_PRINT ("Icon: %s", icon_path); */
@@ -2389,6 +2361,7 @@ anjuta_plugin_manager_activate_plugins (AnjutaPluginManager *plugin_manager,
 						   icon_path);
 			g_free (icon_path);
 			g_free (icon_filename);
+			g_free (title);
 		}
 		
 		if (anjuta_plugin_description_get_string (d, "Anjuta Plugin",
