@@ -18,8 +18,20 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+/**
+ * SECTION:anjuta-preferences-dialog
+ * @short_description: Preferences dialog
+ * @see_also: #AnjutaPreferences
+ * @stability: Unstable
+ * @include: libanjuta/anjuta-preferences-dialog.h
+ * 
+ * Plugins can added preferences page with anjuta_preferences_dialog_add_page().
+ * However, read #AnjutaPreferences for adding proper preferences pages.
+ */
+
 #include <config.h>
 
+#include <string.h>
 #include <glib/gi18n.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkliststore.h>
@@ -34,7 +46,6 @@
 
 #include <cell-renderer-captioned-image.h>
 #include <libanjuta/anjuta-preferences-dialog.h>
-
 struct _AnjutaPreferencesDialogPrivate {
 	GtkWidget *treeview;
 	GtkListStore *store;
@@ -51,75 +62,34 @@ enum {
 };
 
 static void anjuta_preferences_dialog_class_init    (AnjutaPreferencesDialogClass *class);
-static void anjuta_preferences_dialog_instance_init (AnjutaPreferencesDialog      *dlg);
+static void anjuta_preferences_dialog_init (AnjutaPreferencesDialog      *dlg);
 
-GNOME_CLASS_BOILERPLATE (AnjutaPreferencesDialog, 
-			 anjuta_preferences_dialog,
-			 GtkDialog, GTK_TYPE_DIALOG);
-
-static void
-anjuta_preferences_dialog_dispose (GObject *obj)
-{
-	AnjutaPreferencesDialog *dlg = ANJUTA_PREFERENCES_DIALOG (obj);
-
-	if (dlg->priv->store) {
-		g_object_unref (dlg->priv->store);
-		dlg->priv->store = NULL;
-	}
-	
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
-}
+G_DEFINE_TYPE (AnjutaPreferencesDialog, anjuta_preferences_dialog,
+			   GTK_TYPE_DIALOG)
 
 static void
 anjuta_preferences_dialog_finalize (GObject *obj)
 {
 	AnjutaPreferencesDialog *dlg = ANJUTA_PREFERENCES_DIALOG (obj);	
 
-	g_free (dlg->priv);
-
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
-}
-
-#if 0
-static void
-anjuta_preferences_dialog_response (GtkDialog *dialog, int response_id)
-{
-	g_return_if_fail (response_id == 0);
+	if (dlg->priv->store) {
+		g_object_unref (dlg->priv->store);
+		dlg->priv->store = NULL;
+	}
 	
-	gtk_widget_hide (GTK_WIDGET (dialog));
-}
-#endif
-
-static void
-anjuta_preferences_dialog_close (GtkDialog *dialog)
-{
-	gtk_widget_hide (GTK_WIDGET (dialog));
+	g_free (dlg->priv);
+	
+	((GObjectClass *) anjuta_preferences_dialog_parent_class)->finalize (obj);
 }
 
 static void
 anjuta_preferences_dialog_class_init (AnjutaPreferencesDialogClass *class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
-	GtkDialogClass *dialog_class = GTK_DIALOG_CLASS (class);
 
-	parent_class = g_type_class_peek_parent (class);
-	
-	object_class->dispose = anjuta_preferences_dialog_dispose;
 	object_class->finalize = anjuta_preferences_dialog_finalize;
-
-	/* dialog_class->response = anjuta_preferences_dialog_response; */
-	dialog_class->close = anjuta_preferences_dialog_close;
 }
 
-/*
-static gboolean
-delete_event_cb (AnjutaPreferencesDialog *dlg, gpointer data)
-{
-	gtk_widget_hide (GTK_WIDGET (dlg));
-	return FALSE;
-}
-*/
-
 static void
 add_category_columns (AnjutaPreferencesDialog *dlg)
 {
@@ -127,6 +97,7 @@ add_category_columns (AnjutaPreferencesDialog *dlg)
 	GtkTreeViewColumn *column;
 	
 	renderer = anjuta_cell_renderer_captioned_image_new ();
+	g_object_ref_sink (renderer);
 	column = gtk_tree_view_column_new_with_attributes (_("Category"),
 							   renderer,
 							   "text",
@@ -159,12 +130,37 @@ selection_changed_cb (GtkTreeSelection *selection,
 	}
 }
 
+static gint
+compare_pref_page_func (GtkTreeModel *model,
+						GtkTreeIter *a, GtkTreeIter *b, gpointer user_data)
+{
+	gint val;
+	gchar *name1, *name2;
+	
+	gtk_tree_model_get (model, a, COL_TITLE, &name1, -1);
+	gtk_tree_model_get (model, b, COL_TITLE, &name2, -1);
+	
+	/* FIXME: Make the general page first */
+	if (strcmp (name1, _("General")) == 0)
+		return -1;
+		
+	if (strcmp (name2, _("General")) == 0)
+		return 1;
+		
+	val = strcmp (name1, name2);
+	g_free (name1);
+	g_free (name2);
+	
+	return val;
+}
+
 static void
-anjuta_preferences_dialog_instance_init (AnjutaPreferencesDialog *dlg)
+anjuta_preferences_dialog_init (AnjutaPreferencesDialog *dlg)
 {
 	GtkWidget *hbox;
 	GtkWidget *scrolled_window;
 	GtkTreeSelection *selection;
+	GtkTreeSortable *sortable;
 	
 	dlg->priv = g_new0 (AnjutaPreferencesDialogPrivate, 1);
 
@@ -174,13 +170,18 @@ anjuta_preferences_dialog_instance_init (AnjutaPreferencesDialog *dlg)
 	gtk_widget_show (dlg->priv->treeview);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (dlg->priv->treeview),
 					   FALSE);
-
 	dlg->priv->store = gtk_list_store_new (LAST_COL, 
 					       G_TYPE_STRING,
 					       G_TYPE_STRING,
 					       GDK_TYPE_PIXBUF,
 					       GTK_TYPE_WIDGET,
 					       G_TYPE_INT);
+	sortable = GTK_TREE_SORTABLE (dlg->priv->store);
+	gtk_tree_sortable_set_sort_column_id (sortable, COL_TITLE,
+										  GTK_SORT_ASCENDING);
+	gtk_tree_sortable_set_sort_func (sortable, COL_TITLE,
+									 compare_pref_page_func,
+									 NULL, NULL);
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (dlg->priv->treeview),
 				 GTK_TREE_MODEL (dlg->priv->store));
@@ -222,6 +223,8 @@ anjuta_preferences_dialog_instance_init (AnjutaPreferencesDialog *dlg)
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), hbox,
 			    TRUE, TRUE, 0);
 	
+	gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_CLOSE, -7);
+	
 	gtk_widget_show (hbox);
 }
 
@@ -235,8 +238,8 @@ anjuta_preferences_dialog_instance_init (AnjutaPreferencesDialog *dlg)
 GtkWidget *
 anjuta_preferences_dialog_new (void)
 {
-	return gtk_widget_new (ANJUTA_TYPE_PREFERENCES_DIALOG, 
-				 "title", _("Anjuta Preferences Dialog"),
+	return g_object_new (ANJUTA_TYPE_PREFERENCES_DIALOG, 
+				 "title", _("Anjuta Preferences"),
 				 NULL);
 }
 
@@ -286,6 +289,7 @@ anjuta_preferences_dialog_remove_page (AnjutaPreferencesDialog *dlg,
 {
 	GtkTreeModel* model = GTK_TREE_MODEL(dlg->priv->store);
 	GtkTreeIter iter;
+	GtkWidget *page;
 	
 	if (gtk_tree_model_get_iter_first(model, &iter))
 	{
@@ -306,16 +310,18 @@ anjuta_preferences_dialog_remove_page (AnjutaPreferencesDialog *dlg,
 				page_num = gtk_notebook_page_num (
 						GTK_NOTEBOOK(dlg->priv->notebook),
 						GTK_WIDGET (page_widget));
+				
+				page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (dlg->priv->notebook),
+												  page_num);
 
 				gtk_notebook_remove_page(
 						GTK_NOTEBOOK(dlg->priv->notebook), page_num);
+				
+				gtk_widget_destroy (page);
 
 				gtk_list_store_remove(dlg->priv->store, &iter);
-				g_object_unref (page_widget);
 				return;
 			}
-
-			g_object_unref (page_widget);
 		}
 		while (gtk_tree_model_iter_next(model, &iter));
 	}
