@@ -619,7 +619,7 @@ get_property_value_as_string (AnjutaProperty *prop)
 	case ANJUTA_PROPERTY_OBJECT_TYPE_FILE:
 		{
 			const gchar *filename;
-			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (prop->object));
+			filename = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (prop->object));
 			text_value = g_strdup (filename);
 		}
 		break;
@@ -771,13 +771,9 @@ set_property_value_as_string (AnjutaProperty *prop, const gchar *value)
 		{	
 			if (value)
 			{
-				gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (prop->object),
+				gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (prop->object),
 																 value);
 			}
-			else
-			{
-				gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (prop->object), "");
-			}
 		}
 		break;
 	}
@@ -984,7 +980,7 @@ register_callbacks (AnjutaPreferences *pr, AnjutaProperty *p)
 							  G_CALLBACK (update_property_on_change_color), p);
 			break;
 		case ANJUTA_PROPERTY_OBJECT_TYPE_FILE:
-			g_signal_connect (G_OBJECT(p->object), "file-set",
+			g_signal_connect (G_OBJECT(p->object), "current-folder-changed",
 							  G_CALLBACK (update_property_on_change_str), p);
 			break;
 		default:
@@ -1277,6 +1273,14 @@ anjuta_preferences_register_property_custom (AnjutaPreferences *pr,
 	p->get_property = get_property;
 
 	g_hash_table_insert (pr->priv->properties, g_strdup (key), p);
+
+	/* Connect to widget destroy signal so we can automatically unregister
+	 * keys so there aren't any potential conflicts or references to 
+	 * nonexistent widgets on subsequent uses of the prefs dialog. */
+	g_object_set_data (G_OBJECT (p->object), "AnjutaPreferences", pr);
+	g_signal_connect (G_OBJECT (p->object), "destroy",
+					  G_CALLBACK (unregister_preferences_key),
+					  p);
 	return TRUE;
 }
 
