@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifndef _ANJUTA_PREFERENCES_H_
 #define _ANJUTA_PREFERENCES_H_
@@ -25,6 +25,7 @@
 #include <gconf/gconf-client.h>
 
 #include <libanjuta/anjuta-preferences-dialog.h>
+#include <libanjuta/anjuta-plugin-manager.h>
 
 G_BEGIN_DECLS
 
@@ -33,10 +34,11 @@ typedef enum
 	ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
 	ANJUTA_PROPERTY_OBJECT_TYPE_SPIN,
 	ANJUTA_PROPERTY_OBJECT_TYPE_ENTRY,
-	ANJUTA_PROPERTY_OBJECT_TYPE_MENU,
+	ANJUTA_PROPERTY_OBJECT_TYPE_COMBO,
 	ANJUTA_PROPERTY_OBJECT_TYPE_TEXT,
 	ANJUTA_PROPERTY_OBJECT_TYPE_COLOR,
-	ANJUTA_PROPERTY_OBJECT_TYPE_FONT
+	ANJUTA_PROPERTY_OBJECT_TYPE_FONT,
+	ANJUTA_PROPERTY_OBJECT_TYPE_FILE
 } AnjutaPropertyObjectType;
 
 typedef enum
@@ -72,7 +74,7 @@ typedef struct _AnjutaPreferencesPriv    AnjutaPreferencesPriv;
 
 struct _AnjutaPreferences
 {
-	AnjutaPreferencesDialog parent;
+	GObject parent;
 	
 	/*< private >*/
 	AnjutaPreferencesPriv *priv;
@@ -80,7 +82,7 @@ struct _AnjutaPreferences
 
 struct _AnjutaPreferencesClass
 {
-	AnjutaPreferencesDialogClass parent;
+	GObjectClass parent;
 };
 
 typedef gboolean (*AnjutaPreferencesCallback) (AnjutaPreferences *pr,
@@ -89,12 +91,14 @@ typedef gboolean (*AnjutaPreferencesCallback) (AnjutaPreferences *pr,
 
 GType anjuta_preferences_get_type (void);
 
-GtkWidget *anjuta_preferences_new (void);
+AnjutaPreferences *anjuta_preferences_new (AnjutaPluginManager *plugin_manager);
 
 void anjuta_preferences_add_page (AnjutaPreferences* pr, GladeXML *gxml,
 								  const gchar* glade_widget_name,
 								  const gchar* title,
 								  const gchar *icon_filename);
+void anjuta_preferences_remove_page (AnjutaPreferences *pr, 
+									 const gchar *page_name);
 
 /*
  * Registers all properties defined for widgets below the 'parent' widget
@@ -207,6 +211,10 @@ gchar * anjuta_preferences_default_get (AnjutaPreferences *pr,
 /* Gets the value (int) of a key */
 gint anjuta_preferences_default_get_int (AnjutaPreferences *pr,
 												const gchar *key);
+
+/* Dialog methods */
+GtkWidget *anjuta_preferences_get_dialog (AnjutaPreferences *pr);
+
 /* Key notifications */
 guint anjuta_preferences_notify_add (AnjutaPreferences *pr,
 									 const gchar *key,
