@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 /**
@@ -569,7 +569,7 @@ anjuta_profile_add_plugins_from_xml (AnjutaProfile *profile,
 					 ANJUTA_PROFILE_ERROR_URI_READ_FAILED,
 					 _("Failed to read '%s': XML parse error"),
 					 profile_xml_uri);
-		/* FIXME: Free xml doc */
+		xmlFreeDoc(xml_doc);
 		return FALSE;
 	}
 	
@@ -581,6 +581,7 @@ anjuta_profile_add_plugins_from_xml (AnjutaProfile *profile,
 					 _("Failed to read '%s': XML parse error."
 					   "Invalid or corrupted anjuta plugins profile."),
 					 profile_xml_uri);
+		xmlFreeDoc(xml_doc);
 		return FALSE;
 	}
 	
@@ -627,6 +628,7 @@ anjuta_profile_add_plugins_from_xml (AnjutaProfile *profile,
 			mandatory = TRUE;
 		else
 			mandatory = FALSE;
+		xmlFree(mandatory_text);
 		
 		/* For all plugin attribute conditions */
 		xml_require_node = xml_node->xmlChildrenNode;
@@ -730,6 +732,7 @@ anjuta_profile_add_plugins_from_xml (AnjutaProfile *profile,
 					 _("Failed to read '%s': XML parse error."
 					   "Invalid or corrupted anjuta plugins profile."),
 					 profile_xml_uri);
+		xmlFreeDoc(xml_doc);
 		return FALSE;
 	}
 	if (not_found_names)
@@ -768,6 +771,7 @@ anjuta_profile_add_plugins_from_xml (AnjutaProfile *profile,
 		g_list_free (not_found_urls);
 		g_list_free (descs_list);
 		
+		xmlFreeDoc(xml_doc);
 		return FALSE;
 	}
 	if (descs_list)
@@ -801,6 +805,7 @@ anjuta_profile_add_plugins_from_xml (AnjutaProfile *profile,
 		}
 		g_list_free (selected_plugins);
 	}
+	xmlFreeDoc(xml_doc);
 	return TRUE;
 }
 
@@ -838,7 +843,7 @@ anjuta_profile_to_xml (AnjutaProfile *profile)
 				continue;
 			}
 			g_free (user_activatable);
-			
+			/* Do not use the _locale_ version because it's not in UI */
 			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
 												  "Name", &name);
 			DEBUG_PRINT("Saving plugin: %s", name);
@@ -865,10 +870,11 @@ anjuta_profile_to_xml (AnjutaProfile *profile)
 		else
 		{
 			gchar* name;
+			/* Do not use the _locale_ version because it's debugging */
 			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
 												  "Name", &name);
-			DEBUG_PRINT("excluding plugin: %s", name);
-			g_free(name);
+			DEBUG_PRINT ("excluding plugin: %s", name);
+			g_free (name);
 		}
 		node = g_list_next (node);
 	}
