@@ -7,6 +7,7 @@
 #include "ianjuta-debug-manager.h"
 #include "ianjuta-debugger.h"
 #include "ianjuta-debugger-breakpoint.h"
+#include "ianjuta-debugger-variable.h"
 #include "ianjuta-document.h"
 #include "ianjuta-document-manager.h"
 #include "ianjuta-editor.h"
@@ -51,7 +52,6 @@
 #include "ianjuta-symbol-manager.h"
 #include "ianjuta-terminal.h"
 #include "ianjuta-todo.h"
-#include "ianjuta-variable-debugger.h"
 #include "ianjuta-vcs.h"
 #include "ianjuta-wizard.h"
 #include "libanjuta-iface-marshallers.h"
