@@ -408,7 +408,7 @@ on_disassemble (const IAnjutaDebuggerDisassembly *block, DmaSparseBufferTranspor
 	}
 	
 	/* Find following block */
-	DEBUG_PRINT("trans %p buffer %p trans->buffer %p trans->start %ul", trans, buffer, trans == NULL ? NULL : trans->buffer, trans == NULL ? 0 : trans->start);
+	DEBUG_PRINT("trans %p buffer %p trans->buffer %p trans->start %lu", trans, buffer, trans == NULL ? NULL : trans->buffer, trans == NULL ? 0 : trans->start);
 	next = dma_sparse_buffer_lookup (DMA_SPARSE_BUFFER (buffer), trans->start + trans->length - 1);
 	if ((next != NULL) && (next->upper <= trans->start)) next = NULL;
 	
@@ -669,6 +669,17 @@ static DmaSparseViewClass *parent_class = NULL;
 
 static GType dma_disassembly_view_get_type (void);
 
+/* instance_init is the constructor. All functions should work after this
+ * call. */
+
+static void
+dma_disassembly_view_instance_init (DmaSparseView *view)
+{
+	gtk_text_view_set_editable (GTK_TEXT_VIEW (view), FALSE);
+}
+
+/* class_init intialize the class itself not the instance */
+
 static void
 dma_disassembly_view_class_init (DmaDisassemblyViewClass *klass)
 {
@@ -698,7 +709,7 @@ dma_disassembly_view_get_type (void)
 			NULL,           /* class_data */
 			sizeof (DmaDisassemblyView),
 			0,              /* n_preallocs */
-			(GInstanceInitFunc) NULL,
+			(GInstanceInitFunc) dma_disassembly_view_instance_init,
 			NULL            /* value_table */
 		};
 
@@ -735,13 +746,13 @@ on_disassembly_buffer_changed (DmaDisassemblyBuffer *buffer, DmaSparseView *view
 }
 
 static void
-on_breakpoint_changed (DmaDisassemble *self, IAnjutaDebuggerBreakpoint *bp)
+on_breakpoint_changed (DmaDisassemble *self, IAnjutaDebuggerBreakpointItem *bp)
 {
 	g_return_if_fail (bp != NULL);
 	
 	dma_sparse_view_unmark (self->view, bp->address, IANJUTA_MARKABLE_BREAKPOINT_DISABLED);
 	dma_sparse_view_unmark (self->view, bp->address, IANJUTA_MARKABLE_BREAKPOINT_ENABLED);
-	if (!(bp->type & IANJUTA_DEBUGGER_BREAK_REMOVED))
+	if (!(bp->type & IANJUTA_DEBUGGER_BREAKPOINT_REMOVED))
 	{
 		dma_sparse_view_mark (self->view, bp->address, bp->enable ? IANJUTA_MARKABLE_BREAKPOINT_ENABLED : IANJUTA_MARKABLE_BREAKPOINT_DISABLED);
 	}
@@ -797,10 +808,11 @@ on_location_changed (DmaDisassemble *self, guint address, const gchar* uri, guin
 }
 
 static void
-on_debugger_stopped (DmaDisassemble *self)
+on_program_unloaded (DmaDisassemble *self)
 {
-	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_debugger_stopped), self);
+	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_program_unloaded), self);
 	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_breakpoint_changed), self);
+	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_program_running), self);
 	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_program_moved), self);
 	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_location_changed), self);
 
@@ -809,7 +821,6 @@ on_debugger_stopped (DmaDisassemble *self)
 	destroy_disassemble_gui (self);
 }
 
-
 static gboolean
 create_disassemble_gui (DmaDisassemble *self)
 {
@@ -841,19 +852,19 @@ create_disassemble_gui (DmaDisassemble *self)
                              "AnjutaDebuggerDisassemble", _("Disassembly"),
                              NULL, ANJUTA_SHELL_PLACEMENT_LEFT,
 							 NULL);
-	
+
 	return TRUE;
 }
 
 static void
-on_debugger_started (DmaDisassemble *self)
+on_program_loaded (DmaDisassemble *self)
 {
-	if (!(dma_debugger_queue_get_feature (self->debugger) & HAS_CPU)) return;
+	if (!dma_debugger_queue_is_supported (self->debugger, HAS_CPU)) return;
 
 	if (!create_disassemble_gui (self)) return;
 
 	/* Connect signals */
-	g_signal_connect_swapped (self->plugin, "debugger-stopped", G_CALLBACK (on_debugger_stopped), self);
+	g_signal_connect_swapped (self->plugin, "program-unloaded", G_CALLBACK (on_program_unloaded), self);
 	g_signal_connect_swapped (self->plugin, "breakpoint-changed", G_CALLBACK (on_breakpoint_changed), self);
 	g_signal_connect_swapped (self->plugin, "program-running", G_CALLBACK (on_program_running), self);
 	g_signal_connect_swapped (self->plugin, "program-moved", G_CALLBACK (on_program_moved), self);
@@ -863,6 +874,18 @@ on_debugger_started (DmaDisassemble *self)
 /* Public functions
  *---------------------------------------------------------------------------*/
 
+gboolean
+dma_disassemble_is_focus (DmaDisassemble *self)
+{
+	return gtk_widget_is_focus (GTK_WIDGET(self->view));
+}
+
+guint
+dma_disassemble_get_current_address (DmaDisassemble *self)
+{
+	return dma_sparse_view_get_location (self->view);
+}
+
 /* Constructor & Destructor
  *---------------------------------------------------------------------------*/
 
@@ -876,7 +899,7 @@ dma_disassemble_new(DebugManagerPlugin *plugin)
 	self->plugin = plugin;
 	self->debugger = dma_debug_manager_get_queue (plugin);;
 
-	g_signal_connect_swapped (self->plugin, "debugger-started", G_CALLBACK (on_debugger_started), self);
+	g_signal_connect_swapped (self->plugin, "program-loaded", G_CALLBACK (on_program_loaded), self);
 	
 	return self;
 }
