@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef _DISASSEMBLE_H
@@ -23,20 +23,19 @@
 
 G_BEGIN_DECLS
 
+#include "plugin.h"
+
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/interfaces/ianjuta-debugger.h>
 #include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
 
 typedef struct _DmaDisassemble DmaDisassemble;
 
-DmaDisassemble* dma_disassemble_new (AnjutaPlugin *plugin, IAnjutaDebugger *debugger);
+DmaDisassemble* dma_disassemble_new (DebugManagerPlugin *plugin);
 void dma_disassemble_free(DmaDisassemble *self);
 
-void dma_disassemble_mark (DmaDisassemble *self, guint address, gint marker);
-void dma_disassemble_unmark (DmaDisassemble *self, guint address, gint marker);
-void dma_disassemble_goto_address (DmaDisassemble *self, guint address);
-void dma_disassemble_clear_all_mark (DmaDisassemble *self, gint marker);
-
+gboolean dma_disassemble_is_focus (DmaDisassemble *self);
+guint dma_disassemble_get_current_address (DmaDisassemble *self);
 
 G_END_DECLS
 
