@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
  
 #ifdef HAVE_CONFIG_H
@@ -28,12 +28,14 @@
 
 #include <gnome.h>
 
+/*#define DEBUG*/
 #include <libanjuta/anjuta-debug.h>
 
 #include "memory.h"
 
 #include "data_view.h"
 #include "plugin.h"
+#include "queue.h"
 
 /* Constants
  *---------------------------------------------------------------------------*/
@@ -43,7 +45,7 @@
 
 struct _DmaMemory
 {
-	IAnjutaDebugger *debugger;
+	DmaDebuggerQueue *debugger;
 	AnjutaPlugin *plugin;
 	GtkWidget *window;
 	DmaDataBuffer *buffer;
@@ -101,13 +103,12 @@ read_memory_block (gulong address, gulong length, gpointer user_data)
 	
 	if (mem->debugger != NULL)
 	{	
-		ianjuta_cpu_debugger_inspect_memory (
-				IANJUTA_CPU_DEBUGGER (mem->debugger),
+		dma_queue_inspect_memory (
+				mem->debugger,
 				(guint)address,
 				(guint)length,
 				(IAnjutaDebuggerCallback)on_memory_block_read,
-				mem,
-				NULL);
+				mem);
 	}
 }
 
@@ -124,32 +125,6 @@ on_program_stopped (DmaMemory *mem)
 	dma_memory_update (mem);
 }
 
-static void
-create_memory_gui (DmaMemory *mem)
-{
-	GtkWidget *dataview;
-	
-	dataview = dma_data_view_new_with_buffer (mem->buffer);
-	mem->window = dataview;
-	
-	anjuta_shell_add_widget (mem->plugin->shell,
-							 mem->window,
-                             "AnjutaDebuggerMemory", _("Memory"),
-                             NULL, ANJUTA_SHELL_PLACEMENT_CENTER,
-							 NULL);
-
-}
-
-static void
-on_debugger_started (DmaMemory *mem)
-{
-	if (mem->buffer == NULL)
-	{
-		mem->buffer = dma_data_buffer_new (0x0000, 0xFFFFFFFFU, read_memory_block, NULL, mem);
-	}
-	create_memory_gui (mem);
-}
-
 static void
 destroy_memory_gui (DmaMemory *mem)
 {
@@ -165,32 +140,78 @@ destroy_memory_gui (DmaMemory *mem)
 		mem->window = NULL;
 		dma_data_buffer_remove_all_page (mem->buffer);
 	}
+	
+	/* Remove buffer */		
+	if (mem->buffer != NULL)
+	{	
+		g_object_unref (mem->buffer);
+		mem->buffer = NULL;
+	}
 }
 
 static void
 on_debugger_stopped (DmaMemory *mem)
 {
+	
+	g_signal_handlers_disconnect_by_func (mem->plugin, G_CALLBACK (on_debugger_stopped), mem);
+	g_signal_handlers_disconnect_by_func (mem->plugin, G_CALLBACK (on_program_stopped), mem);
+	
 	destroy_memory_gui (mem);
 }
 
+static gboolean
+create_memory_gui (DmaMemory *mem)
+{
+	GtkWidget *dataview;
+
+	g_return_val_if_fail (mem->buffer == NULL, FALSE);
+	g_return_val_if_fail (mem->window == NULL, FALSE);
+	
+	mem->buffer = dma_data_buffer_new (0x0000, 0xFFFFFFFFU, read_memory_block, NULL, mem);
+	if (mem->buffer == NULL) return FALSE;
+	
+	dataview = dma_data_view_new_with_buffer (mem->buffer);
+	mem->window = dataview;
+	
+	anjuta_shell_add_widget (mem->plugin->shell,
+							 mem->window,
+                             "AnjutaDebuggerMemory", _("Memory"),
+                             NULL, ANJUTA_SHELL_PLACEMENT_CENTER,
+							 NULL);
+	
+	return TRUE;
+}
+
+static void
+on_debugger_started (DmaMemory *mem)
+{
+	/* Keep graphical interface if already existing, could happens after
+	 * unloading a program in the debugger */
+	if (mem->window) return;
+	
+	if (!dma_debugger_queue_is_supported (mem->debugger, HAS_CPU)) return;
+
+	if (!create_memory_gui (mem)) return;
+
+	/* Connect signals */
+	g_signal_connect_swapped (mem->plugin, "debugger-stopped", G_CALLBACK (on_debugger_stopped), mem);
+	g_signal_connect_swapped (mem->plugin, "program-stopped", G_CALLBACK (on_program_stopped), mem);
+}
+
 /* Constructor & Destructor
  *---------------------------------------------------------------------------*/
 
 DmaMemory*
-dma_memory_new(AnjutaPlugin *plugin, IAnjutaDebugger *debugger)
+dma_memory_new(DebugManagerPlugin *plugin)
 {
 	DmaMemory* mem;
 	
 	mem = g_new0 (DmaMemory, 1);
 	
-	mem->debugger = debugger;
-	if (debugger != NULL) g_object_ref (debugger);
-	mem->plugin = plugin;
-	mem->buffer = NULL;
+	mem->debugger = dma_debug_manager_get_queue (plugin);
+	mem->plugin = ANJUTA_PLUGIN (plugin);
 
-	g_signal_connect_swapped (mem->debugger, "debugger-started", G_CALLBACK (on_debugger_started), mem);
-	g_signal_connect_swapped (mem->debugger, "debugger-stopped", G_CALLBACK (on_debugger_stopped), mem);
-	g_signal_connect_swapped (mem->debugger, "program-stopped", G_CALLBACK (on_program_stopped), mem);
+	g_signal_connect_swapped (mem->plugin, "debugger-started", G_CALLBACK (on_debugger_started), mem);
 
 	return mem;
 }
@@ -200,11 +221,10 @@ dma_memory_free(DmaMemory* mem)
 {
 	g_return_if_fail (mem != NULL);
 
-	destroy_memory_gui (mem);
+	g_signal_handlers_disconnect_matched (mem->plugin, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, mem);	
 	
-	if (mem->buffer != NULL) g_object_unref (mem->buffer);
+	destroy_memory_gui (mem);
 
-	if (mem->debugger != NULL)	g_object_unref (mem->debugger);
 	g_free(mem);
 }
 
