@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef _MEMORY_H
@@ -23,13 +23,15 @@
 
 G_BEGIN_DECLS
 
+#include "plugin.h"
+
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/interfaces/ianjuta-debugger.h>
 #include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
 
 typedef struct _DmaMemory DmaMemory;
 
-DmaMemory* dma_memory_new (AnjutaPlugin *plugin, IAnjutaDebugger *debugger);
+DmaMemory* dma_memory_new (DebugManagerPlugin *plugin);
 void dma_memory_free(DmaMemory *this);
 
 G_END_DECLS
