@@ -25,8 +25,6 @@
 #include "plugin.h"
 
 #include "breakpoints.h"
-#include "watch.h"
-#include "locals.h"
 #include "stack_trace.h"
 #include "threads.h"
 #include "info.h"
@@ -38,6 +36,7 @@
 #include "utilities.h"
 #include "start.h"
 #include "queue.h"
+#include "variable.h"
 
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
@@ -90,8 +89,6 @@ struct _DebugManagerPlugin
 	gboolean busy;
 	
 	/* Debugger components */
-	Locals *locals;
-	ExprWatch *watch;
 	BreakpointsDBase *breakpoints;
 	DmaStart *start;
 	StackTrace *stack;
@@ -101,6 +98,7 @@ struct _DebugManagerPlugin
 	DmaMemory *memory;
 	DmaDisassemble *disassemble;
 	DmaThreads *thread;
+	DmaVariableDBase *variable;
 	
 	
 	/* Logging view */
@@ -204,7 +202,7 @@ set_program_counter(DebugManagerPlugin *self, const gchar* file, guint line, gui
 	if (file != NULL)
 	{
 		docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (self)->shell, IAnjutaDocumentManager, NULL);
-		file_uri = g_strconcat ("file://", file, NULL);
+		file_uri = gnome_vfs_get_uri_from_local_path(file);
 		if (docman)
 		{
 			IAnjutaEditor* editor;
@@ -266,6 +264,8 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	self = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
 
 	editor = g_value_get_object (value);
+	DEBUG_PRINT("add value current editor %p",  editor);
+	
 	if (!IANJUTA_IS_EDITOR(editor))
 	{
 		self->current_editor = NULL;
@@ -275,9 +275,6 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	self->current_editor = IANJUTA_EDITOR (editor);
 	g_object_add_weak_pointer (G_OBJECT (self->current_editor), (gpointer *)(gpointer)&self->current_editor);
 		
-    /* Restore breakpoints */
-	breakpoints_dbase_set_all_in_editor (self->breakpoints, self->current_editor);
-	
 	/* Restore program counter marker */
 	show_program_counter_in_editor (self);
 }
@@ -288,11 +285,9 @@ value_removed_current_editor (AnjutaPlugin *plugin,
 {
 	DebugManagerPlugin *self = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
 
+	DEBUG_PRINT("remove value current editor %p", self->current_editor);
 	if (self->current_editor)
 	{
-		breakpoints_dbase_clear_all_in_editor (self->breakpoints,
-            self->current_editor);
-	
 		hide_program_counter_in_editor (self);
 
 		g_object_remove_weak_pointer (G_OBJECT (self->current_editor), (gpointer *)(gpointer)&self->current_editor);
@@ -629,14 +624,32 @@ static void
 on_step_in_action_activate (GtkAction* action, DebugManagerPlugin* plugin)
 {
 	if (plugin->queue)
-		dma_queue_step_in (plugin->queue);
+	{
+		if ((plugin->disassemble != NULL) && (dma_disassemble_is_focus (plugin->disassemble)))
+		{
+			dma_queue_stepi_in (plugin->queue);
+		}
+		else
+		{
+			dma_queue_step_in (plugin->queue);
+		}
+	}
 }
 
 static void
 on_step_over_action_activate (GtkAction* action, DebugManagerPlugin* plugin)
 {
 	if (plugin->queue)
-		dma_queue_step_over (plugin->queue);
+	{
+		if ((plugin->disassemble != NULL) && (dma_disassemble_is_focus (plugin->disassemble)))
+		{
+			dma_queue_stepi_over (plugin->queue);
+		}
+		else
+		{
+			dma_queue_step_over (plugin->queue);
+		}
+	}
 }
 
 static void
@@ -649,37 +662,37 @@ on_step_out_action_activate (GtkAction* action, DebugManagerPlugin* plugin)
 static void
 on_run_to_cursor_action_activate (GtkAction* action, DebugManagerPlugin* plugin)
 {
-	IAnjutaDocumentManager *docman;
-	IAnjutaEditor *editor;
-	IAnjutaDocument *document;
-	gchar *uri;
-	gchar *file;
-	gint line;
+	if (plugin->queue)
+	{
+		if ((plugin->disassemble != NULL) && (dma_disassemble_is_focus (plugin->disassemble)))
+		{
+			guint address;
+			
+			address = dma_disassemble_get_current_address (plugin->disassemble);
+			dma_queue_run_to_address (plugin->queue, address);
+		}
+		else
+		{
+			IAnjutaEditor *editor;
+			gchar *uri;
+			gchar *file;
+			gint line;
 
-	if (plugin->queue == NULL)
-		return;
+			editor = dma_get_current_editor (ANJUTA_PLUGIN (plugin));
+			if (editor == NULL)
+				return;
+			uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
+			if (uri == NULL)
+				return;
 	
-	docman = IANJUTA_DOCUMENT_MANAGER (anjuta_shell_get_object (ANJUTA_PLUGIN (plugin)->shell, "IAnjutaDocumentManager", NULL));
-	if (docman == NULL)
-		return;
+			file = gnome_vfs_get_local_path_from_uri (uri);
 	
-	document = ianjuta_document_manager_get_current_document (docman, NULL);
-	if (IANJUTA_IS_DOCUMENT(document))
-	{	
-		editor = IANJUTA_EDITOR(document);
+			line = ianjuta_editor_get_lineno (editor, NULL);
+			dma_queue_run_to (plugin->queue, file, line);
+			g_free (uri);
+			g_free (file);
+		}
 	}
-	else
-		return;
-	uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
-	if (uri == NULL)
-		return;
-	
-	file = gnome_vfs_get_local_path_from_uri (uri);
-	
-	line = ianjuta_editor_get_lineno (editor, NULL);
-	dma_queue_run_to (plugin->queue, file, line);
-	g_free (uri);
-	g_free (file);
 }
 
 static void
@@ -1094,13 +1107,9 @@ dma_plugin_activate (AnjutaPlugin* plugin)
 											GETTEXT_PACKAGE, TRUE, this);	
 	this->uiid = anjuta_ui_merge (ui, UI_FILE);
 
+	/* Variable */
+	this->variable = dma_variable_dbase_new (this);
 	
-	/* Watch expression */
-	this->watch = expr_watch_new (ANJUTA_PLUGIN (this));
-	
-	/* Local window */
-	this->locals = locals_new (this);
-
 	/* Stack trace */
 	this->stack = stack_trace_new (this);
 
@@ -1169,15 +1178,12 @@ dma_plugin_deactivate (AnjutaPlugin* plugin)
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	anjuta_ui_unmerge (ui, this->uiid);
 
-    expr_watch_destroy (this->watch);
-	this->watch = NULL;
+	dma_variable_dbase_free (this->variable);
+	this->variable = NULL;
 	
 	breakpoints_dbase_destroy (this->breakpoints);
 	this->breakpoints = NULL;
 	
-	locals_free (this->locals);
-	this->locals = NULL;
-	
 	stack_trace_free (this->stack);
 	this->stack = NULL;
 
@@ -1243,8 +1249,6 @@ dma_plugin_instance_init (GObject* obj)
 	plugin->editor_watch_id = 0;
 	plugin->project_watch_id = 0;
 	plugin->breakpoints = NULL;
-	plugin->watch = NULL;
-	plugin->locals = NULL;
 	plugin->registers = NULL;
 	plugin->signals = NULL;
 	plugin->sharedlibs = NULL;
