@@ -15,12 +15,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef _REGISTERS_H_
 #define _REGISTERS_H_
 
+#include "plugin.h"
+
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/interfaces/ianjuta-debugger.h>
 #include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
@@ -29,7 +31,7 @@
 
 typedef struct _CpuRegisters CpuRegisters;
 
-CpuRegisters* cpu_registers_new (AnjutaPlugin *plugin, IAnjutaDebugger *debugger);
+CpuRegisters* cpu_registers_new (DebugManagerPlugin *plugin);
 void cpu_registers_free(CpuRegisters *this);
 
 #endif
