@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef _START_H_
@@ -27,11 +27,12 @@
 
 typedef struct _DmaStart DmaStart;
 
-DmaStart *dma_start_new (AnjutaPlugin *plugin, IAnjutaDebugger *debugger);
+DmaStart *dma_start_new (DebugManagerPlugin *plugin);
 void dma_start_free (DmaStart *this);
 
 void dma_attach_to_process (DmaStart *this);
 gboolean dma_run_target (DmaStart *this);
 gboolean dma_rerun_target (DmaStart *this);
+gboolean dma_quit_debugger (DmaStart *this);
 
 #endif
