@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifndef _TEXT_EDITOR_H_
 #define _TEXT_EDITOR_H_
@@ -112,6 +112,8 @@ struct _TextEditor
 	 */
 	gint file_modified_timer;
 	GtkWidget *file_modified_widget;
+	
+	gboolean hover_tip_on;
 };
 
 struct _TextEditorClass
@@ -215,6 +217,8 @@ gint     text_editor_set_indicator (TextEditor *te, gint start, gint end,
 gboolean text_editor_can_undo (TextEditor *te);
 gboolean text_editor_can_redo (TextEditor *te);
 
+gchar* text_editor_get_word_before_carat (TextEditor *te);
+
 /* Get currect word near by cursor location */
 gchar* text_editor_get_current_word (TextEditor *te);
 
@@ -237,6 +241,10 @@ void text_editor_set_busy (TextEditor *te, gboolean state);
 void text_editor_add_view (TextEditor *te);
 void text_editor_remove_view (TextEditor *te);
 
+/* Show/hide hover tips */
+void text_editor_show_hover_tip (TextEditor *te, gint position, const gchar *info);
+void text_editor_hide_hover_tip (TextEditor *te);
+
 /* Direct editor commands to AnEditor and Scintilla */
 void text_editor_command(TextEditor *te, gint command,
 						 glong wparam, glong lparam);
