@@ -23,6 +23,8 @@
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 
+#include <glib/gi18n.h>
+
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-status.h>
 #include <libanjuta/anjuta-debug.h>
@@ -48,14 +50,14 @@ sort_wizards(gconstpointer wizard1, gconstpointer wizard2)
 	AnjutaPluginDescription* desc1 = (AnjutaPluginDescription*) wizard1;
 	AnjutaPluginDescription* desc2 = (AnjutaPluginDescription*) wizard2;
 	
-	if ((anjuta_plugin_description_get_string (desc1, "Wizard",
-												  "Title", &name1) ||
-			anjuta_plugin_description_get_string (desc1, "Anjuta Plugin",
-												  "Name", &name1)) &&
-		(anjuta_plugin_description_get_string (desc2, "Wizard",
-												  "Title", &name2) ||
-			anjuta_plugin_description_get_string (desc2, "Anjuta Plugin",
-												  "Name", &name2)))
+	if ((anjuta_plugin_description_get_locale_string (desc1, "Wizard",
+													  "Title", &name1) ||
+			anjuta_plugin_description_get_locale_string (desc1, "Anjuta Plugin",
+														 "Name", &name1)) &&
+		(anjuta_plugin_description_get_locale_string (desc2, "Wizard",
+													  "Title", &name2) ||
+			anjuta_plugin_description_get_locale_string (desc2, "Anjuta Plugin",
+														 "Name", &name2)))
 	{
 		return strcmp(name1, name2);
 	}
@@ -182,13 +184,13 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 		
 		name = NULL;
 		
-		anjuta_plugin_description_get_string (desc, "File Loader",
-											  "Title", &name);
+		anjuta_plugin_description_get_locale_string (desc, "File Loader",
+													 "Title", &name);
 		
 		if (!name)
 		{
-			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-												  "Name", &name);
+			anjuta_plugin_description_get_locale_string (desc, "Anjuta Plugin",
+														 "Name", &name);
 		}
 		if (!name)
 		{
@@ -591,16 +593,16 @@ on_create_submenu (gpointer user_data)
 		
 		icon = NULL;
 		name = NULL;
-		if (anjuta_plugin_description_get_string (desc, "Wizard",
-												  "Title", &str) ||
-			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-												  "Name", &str))
+		if (anjuta_plugin_description_get_locale_string (desc, "Wizard",
+														 "Title", &str) ||
+			anjuta_plugin_description_get_locale_string (desc, "Anjuta Plugin",
+														 "Name", &str))
 		{
 			count++;
 			if (count < 10)
-				name = g_strdup_printf ("_%d. %s", count, str);
+				name = g_strdup_printf ("_%d. %s", count, N_(str));
 			else
-				name = g_strdup_printf ("%d. %s", count, str);
+				name = g_strdup_printf ("%d. %s", count, N_(str));
 			g_free (str);
 		}
 		if (anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
@@ -834,12 +836,12 @@ create_open_with_submenu (AnjutaFileLoaderPlugin *plugin, GtkWidget *parentmenu,
 		
 		desc = (AnjutaPluginDescription *)(snode->data);
 		name = NULL;
-		anjuta_plugin_description_get_string (desc, "File Loader",
-											  "Title", &name);
+		anjuta_plugin_description_get_locale_string (desc, "File Loader",
+													 "Title", &name);
 		if (!name)
 		{
-			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-												  "Name", &name);
+			anjuta_plugin_description_get_locale_string (desc, "Anjuta Plugin",
+														 "Name", &name);
 		}
 		if (!name)
 		{
