@@ -174,12 +174,14 @@ glade_do_close (GladePlugin *plugin, GladeProject *project)
 }
 
 static void
-on_close_activated (GtkWidget* document, GladePlugin *plugin)
+on_document_destroy (GtkWidget* document, GladePlugin *plugin)
 {
 	GladeProject *project;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	
+	IAnjutaDocumentManager *docman;
+	GList *docwids, *node;
+
 	DEBUG_PRINT(__FUNCTION__);
 	
 	if (plugin->priv->destroying)
@@ -215,8 +217,6 @@ on_close_activated (GtkWidget* document, GladePlugin *plugin)
 
 	if (gtk_tree_model_iter_n_children (model, NULL) <= 0)
 		anjuta_plugin_deactivate (ANJUTA_PLUGIN (plugin));
-	
-	DEBUG_PRINT(__FUNCTION__);
 }
 
 static void
@@ -224,7 +224,7 @@ on_shell_destroy (AnjutaShell* shell, GladePlugin *glade_plugin)
 {
 	glade_plugin->priv->destroying = TRUE;
 }
-	
+
 static void
 on_glade_project_changed (GtkComboBox *combo, GladePlugin *plugin)
 {
@@ -264,7 +264,7 @@ register_stock_icons (AnjutaPlugin *plugin)
 
 	/* Register stock icons */
 	BEGIN_REGISTER_ICON (plugin);
-	REGISTER_ICON (PACKAGE_PIXMAPS_DIR"/anjuta-glade-plugin-48.png",
+	REGISTER_ICON ("anjuta-glade-plugin-48.png",
 				   "glade-plugin-icon");
 	END_REGISTER_ICON;
 }
@@ -273,47 +273,93 @@ static void
 on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 				 AnjutaSession *session, GladePlugin *plugin)
 {
-	GList *files;
-	GtkTreeModel *model;
+	GList *files, *docwids, *node;
+/*	GtkTreeModel *model;
 	GtkTreeIter iter;
+*/
+	IAnjutaDocumentManager *docman;
 	
 	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
 		return;
 	
+	docman = anjuta_shell_get_interface (ANJUTA_PLUGIN(plugin)->shell,
+										 IAnjutaDocumentManager, NULL);
+	docwids = ianjuta_document_manager_get_doc_widgets (docman, NULL);
+	if (docwids)
+	{
+		files = anjuta_session_get_string_list (session, "File Loader", "Files");
+		if (files)
+			files = g_list_reverse (files);
+		for (node = docwids; node != NULL; node = g_list_next (node))
+		{
+			if (ANJUTA_IS_DESIGN_DOCUMENT (node->data))
+			{
+				gchar *uri;
+				uri = ianjuta_file_get_uri (IANJUTA_FILE (node->data), NULL);
+				if (uri != NULL)
+				{
+					files = g_list_prepend (files, uri);
+					/* uri is not freed here */
+				}
+			}
+		}
+		g_list_free (docwids);
+		if (files)
+		{
+			files = g_list_reverse (files);
+			anjuta_session_set_string_list (session, "File Loader", "Files", files);
+			g_list_foreach (files, (GFunc)g_free, NULL);
+			g_list_free (files);
+		}
+	}
+/*
 	files = anjuta_session_get_string_list (session, "File Loader", "Files");
-	files = g_list_reverse (files);
+	if (files)
+		files = g_list_reverse (files);
 	
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (plugin->priv->projects_combo));
 	if (gtk_tree_model_get_iter_first (model, &iter))
 	{
 		do
 		{
+#if (GLADEUI_VERSION >= 330)
+			const gchar *ppath;
+#endif
 			gchar *uri;
 			GladeProject *project;
 			gtk_tree_model_get (model, &iter, PROJECT_COL, &project, -1);
 #if (GLADEUI_VERSION >= 330)
-			if (glade_project_get_path(project))
+			ppath = glade_project_get_path (project);
+			if (ppath)
 #else
 			if (project->path)
 #endif
 			{
+				uri = gnome_vfs_get_uri_from_local_path (
 #if (GLADEUI_VERSION >= 330)
-				uri = gnome_vfs_get_uri_from_local_path
-							(glade_project_get_path(project));
+					ppath);
 #else
-				uri = gnome_vfs_get_uri_from_local_path (project->path);
+					project->path);
 #endif
 				if (uri)
+				{
+					/ * FIXME only log file if it's still open in docman * /
 					files = g_list_prepend (files, uri);
-				/* URI is not freed here */
+					/ * uri is not freed here * /
+				}
 			}
 		}
 		while (gtk_tree_model_iter_next (model, &iter));
 	}
-	files = g_list_reverse (files);
-	anjuta_session_set_string_list (session, "File Loader", "Files", files);
-	g_list_foreach (files, (GFunc)g_free, NULL);
-	g_list_free (files);
+
+	if (files)
+	{
+		files = g_list_reverse (files);
+		anjuta_session_set_string_list (session, "File Loader", "Files", files);
+		g_list_foreach (files, (GFunc)g_free, NULL);
+		g_list_free (files);
+	}
+*/
 }
 
 static void
@@ -329,12 +375,13 @@ glade_plugin_add_project (GladePlugin *glade_plugin, GladeProject *project)
  	
 	priv = glade_plugin->priv;
  	view = anjuta_design_document_new(glade_plugin, project);
-	g_signal_connect(G_OBJECT(view), "destroy", G_CALLBACK(on_close_activated), glade_plugin);
+	g_signal_connect (G_OBJECT(view), "destroy",
+					  G_CALLBACK (on_document_destroy), glade_plugin);
 	gtk_widget_show (view);
 	g_object_set_data (G_OBJECT (project), "design_view", view);
-	glade_app_add_project (project);
-	
+	/* add document before adding project, cuz that changes the document */
 	ianjuta_document_manager_add_document(docman, IANJUTA_DOCUMENT(view), NULL);
+	glade_app_add_project (project);
 }
 
 #if (GLADEUI_VERSION >= 330)
@@ -583,8 +630,8 @@ ifile_open (IAnjutaFile *ifile, const gchar *uri, GError **err)
 	GtkTreeIter iter;
 	gchar *filename;
 	IAnjutaDocumentManager* docman;
-	GList* docs;
-	GList* cur_doc;
+	GList* docwids;
+	GList* node;
 	
 	g_return_if_fail (uri != NULL);
 	
@@ -600,26 +647,31 @@ ifile_open (IAnjutaFile *ifile, const gchar *uri, GError **err)
 	
 	docman = anjuta_shell_get_interface(ANJUTA_PLUGIN(ifile)->shell, IAnjutaDocumentManager,
 										NULL);
-	docs = ianjuta_document_manager_get_documents(docman, NULL);
-	for (cur_doc = docs; cur_doc != NULL; cur_doc = g_list_next(cur_doc))
+	docwids = ianjuta_document_manager_get_doc_widgets (docman, NULL);
+	if (docwids)
 	{
-		if (ANJUTA_IS_DESIGN_DOCUMENT(cur_doc->data))
+		for (node = docwids; node != NULL; node = g_list_next (node))
 		{
-			gchar *cur_uri;
-			cur_uri = ianjuta_file_get_uri (IANJUTA_FILE (cur_doc->data), NULL);
-			if (cur_uri)
+			if (ANJUTA_IS_DESIGN_DOCUMENT (node->data))
 			{
-			DEBUG_PRINT("%s = %s", uri, cur_uri);
-				if (g_str_equal (uri, cur_uri))
-			{
-					ianjuta_document_manager_set_current_document (docman,
-						IANJUTA_DOCUMENT (cur_doc->data), NULL);
+				gchar *cur_uri;
+				cur_uri = ianjuta_file_get_uri (IANJUTA_FILE (node->data), NULL);
+				if (cur_uri)
+				{
+					DEBUG_PRINT("%s = %s", uri, cur_uri);
+					if (g_str_equal (uri, cur_uri))
+					{
+						ianjuta_document_manager_set_current_document (docman,
+							IANJUTA_DOCUMENT (node->data), NULL);
+						g_free (cur_uri);
+						g_list_free (docwids);
+						return;
+					}
 					g_free (cur_uri);
-				return;
-			}
-				g_free (cur_uri);
+				}
 			}
 		}
+		g_list_free (docwids);
 	}
 	
 #if (GLADEUI_VERSION >= 330)
