@@ -726,19 +726,22 @@ on_assist_chosen (IAnjutaEditorAssist* iassist, gint selection,
 	ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (te), NULL);
 	if (pre_word)
 	{
-		gint sel_start;
-		sel_start = ianjuta_iterable_get_position (iter, NULL);
+		IAnjutaIterable *cursor_iter =
+			ianjuta_editor_get_cell_iter (te, cur_pos, NULL);
+		ianjuta_iterable_next (iter, NULL);
 		ianjuta_editor_selection_set (IANJUTA_EDITOR_SELECTION (te),
-									  sel_start + 1, cur_pos, FALSE, NULL);
+									  iter, cursor_iter, NULL);
 		ianjuta_editor_selection_replace (IANJUTA_EDITOR_SELECTION (te),
 										  assistance->str, -1, NULL);
+		g_object_unref (cursor_iter);
 		g_free (pre_word);
 	}
 	else
 	{
 		ianjuta_editor_insert (te, cur_pos, assistance->str, -1, NULL);
 	}
-	
+	g_object_unref (iter);
+
 	ianjuta_document_end_undo_action (IANJUTA_DOCUMENT (te), NULL);
 	
 	ianjuta_editor_assist_hide_suggestions (assist->priv->iassist, NULL);
@@ -747,7 +750,6 @@ on_assist_chosen (IAnjutaEditorAssist* iassist, gint selection,
 	if (add_brace_after_func)
 		cpp_java_assist_check (assist, FALSE, TRUE);
 	
-	g_object_unref (iter);
 	g_string_free (assistance, TRUE);
 }
 
