@@ -27,7 +27,7 @@
  * list of people on the anjuta Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: anjuta-document.c 3181 2007-09-27 14:09:40Z jhs $
+ * $Id: anjuta-document.c 3415 2008-01-05 13:15:41Z jhs $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,7 +49,6 @@
 #include "anjuta-utils.h"
 
 #include <gtksourceview/gtksourceiter.h>
-#include <gtksourceview/gtksourcelanguagesmanager.h>
 #include <pcre.h>
 
 #define ANJUTA_MAX_PATH_LEN  2048
@@ -77,8 +76,6 @@ struct _AnjutaDocumentPrivate
 	GnomeVFSURI *vfs_uri;
 
 	const AnjutaEncoding *encoding;
-	GtkSourceLanguagesManager* lang_manager;
-
 
 	time_t       mtime;
 
@@ -424,7 +421,7 @@ anjuta_document_init (AnjutaDocument *doc)
 
 	doc->priv->encoding = anjuta_encoding_get_utf8 ();
 
-	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (doc), 
+	gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (doc), 
 					     TRUE);
 
 	g_signal_connect_after (doc, 
