@@ -27,7 +27,7 @@
  * list of people on the anjuta Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: anjuta-view.c 3216 2007-10-14 19:59:37Z jhs $ 
+ * $Id: anjuta-view.c 3427 2008-01-06 14:09:57Z jhs $ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -336,14 +336,14 @@ anjuta_view_init (AnjutaView *view)
 	 */
 		
 	g_object_set (G_OBJECT (view), 
-		      "wrap_mode", FALSE,
-		      "show_line_numbers", TRUE,
-		      "auto_indent", TRUE,
-		      "tabs_width", 4,
-		      "insert_spaces_instead_of_tabs", FALSE,
-		      "highlight_current_line", TRUE, 
-          "indent_on_tab", TRUE, /* Fix #388727 */
-		      "smart_home_end", FALSE, /* Never changes this */
+		      "wrap-mode", FALSE,
+		      "show-line-numbers", TRUE,
+		      "auto-indent", TRUE,
+		      "tab-width", 4,
+		      "insert-spaces-instead-of-tabs", FALSE,
+		      "highlight-current-line", TRUE, 
+          "indent-on-tab", TRUE, /* Fix #388727 */
+		      "smart-home-end", FALSE, /* Never changes this */
 		      NULL);
 }
 
@@ -686,9 +686,6 @@ anjuta_view_set_colors (AnjutaView *view,
 		rc_style->color_flags [GTK_STATE_ACTIVE] = 0;
 
 		gtk_widget_modify_style (GTK_WIDGET (view), rc_style);
-
-		/* It must be called after the text color has been modified */
-		modify_cursor_color (GTK_WIDGET (view), NULL);
 	}
 }
 
@@ -815,7 +812,10 @@ anjuta_view_key_press_event		(GtkWidget *widget, GdkEventKey       *event)
 							 event->keyval == GDK_Down)
 			{
 				if (assist_tip)
+        {
 					gtk_widget_destroy (GTK_WIDGET(assist_tip));
+          return retval;
+        }
 			}
 			else if (event->keyval == GDK_Left || event->keyval == GDK_Right ||
 							 event->keyval == GDK_Up || event->keyval == GDK_Down ||
