@@ -52,7 +52,7 @@
 #define GLADE_FILE ANJUTA_DATA_DIR"/glade/symbol-db.glade"
 #define ICON_FILE "anjuta-symbol-db-plugin-48.png"
 
-#define TIMEOUT_INTERVAL_SYMBOLS_UPDATE		15000
+#define TIMEOUT_INTERVAL_SYMBOLS_UPDATE		10000
 #define TIMEOUT_SECONDS_AFTER_LAST_TIP		5
 
 static gpointer parent_class;
@@ -75,28 +75,6 @@ register_stock_icons (AnjutaPlugin *plugin)
 	REGISTER_ICON (ICON_FILE, "symbol-db-plugin-icon");
 	END_REGISTER_ICON;
 }
-/*
-static GtkActionEntry actions[] = 
-{
-	{ "ActionMenuGoto", NULL, N_("_Goto"), NULL, NULL, NULL},
-	{
-		"ActionSymbolBrowserGotoDef",
-		NULL,
-		N_("Tag _Definition"),
-		"<control>d",
-		N_("Goto symbol definition"),
-		G_CALLBACK (on_goto_file_tag_def_activate)
-	},
-	{
-		"ActionSymbolBrowserGotoDecl",
-		NULL,
-		N_("Tag De_claration"),
-		"<shift><control>d",
-		N_("Goto symbol declaration"),
-		G_CALLBACK (on_goto_file_tag_decl_activate)
-	}
-};
-*/
 
 static gboolean
 on_editor_buffer_symbols_update_timeout (gpointer user_data)
@@ -190,15 +168,16 @@ static void
 on_editor_destroy (SymbolDBPlugin *sdb_plugin, IAnjutaEditor *editor)
 {
 	const gchar *uri;
-	
+	DEBUG_PRINT ("on_editor_destroy ()");
 	if (!sdb_plugin->editor_connected || !sdb_plugin->dbv_view_tree)
 		return;
 	
 	uri = g_hash_table_lookup (sdb_plugin->editor_connected, G_OBJECT (editor));
 	if (uri && strlen (uri) > 0)
 	{
+/*				
 		DEBUG_PRINT ("Removing file tags of %s", uri);
-/*		
+
 		anjuta_symbol_view_workspace_remove_file (ANJUTA_SYMBOL_VIEW (sv_plugin->sv_tree),
 											   uri);
 */		
@@ -209,6 +188,16 @@ on_editor_destroy (SymbolDBPlugin *sdb_plugin, IAnjutaEditor *editor)
 static void
 on_editor_update_ui (IAnjutaEditor *editor, SymbolDBPlugin *sdb_plugin) 
 {
+	if (timer == NULL)
+	{
+		/* creates and start a new timer. */
+		timer = g_timer_new ();
+	}
+	else 
+	{
+		g_timer_reset (timer);
+	}
+	
 #if 0	
 	gint lineno = ianjuta_editor_get_lineno (editor, NULL);
 	
@@ -309,8 +298,6 @@ on_editor_saved (IAnjutaEditor *editor, const gchar *saved_uri,
 	}
 }
 
-
-//files = anjuta_session_get_string_list (session, "File Loader", "Files");
 static void
 value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 							const GValue *value, gpointer data)
@@ -323,6 +310,8 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	editor = g_value_get_object (value);	
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
 	
+	DEBUG_PRINT ("value_removed_current_editor ()");
+		
 	if (!sdb_plugin->editor_connected)
 	{
 		sdb_plugin->editor_connected = g_hash_table_new_full (g_direct_hash,
@@ -330,13 +319,25 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 															 NULL, g_free);
 	}
 	sdb_plugin->current_editor = editor;
-
+	
+	if (!IANJUTA_IS_EDITOR (editor))
+		return;
+	
 	uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
 	
 	if (uri == NULL)
 		return;
 
 	local_path = gnome_vfs_get_local_path_from_uri (uri);
+	DEBUG_PRINT ("value_added_current_editor () gonna refresh local syms: local_path %s "
+				 "uri %s", local_path, uri);
+	
+	if (strstr (local_path, "//") != NULL)
+	{
+		g_critical ("WARNING FIXME: bad file uri passed to symbol-db from editor. There's "
+				   "a trailing slash left. Please fix this at editor side");
+	}
+	 
 	symbol_db_view_locals_update_list (
 				SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals),
 				 sdb_plugin->sdbe, local_path);
@@ -359,8 +360,7 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 
 		g_signal_connect (G_OBJECT (editor), "saved",
 						  G_CALLBACK (on_editor_saved),
-						  sdb_plugin);
-						  
+						  sdb_plugin);						  
 		g_signal_connect (G_OBJECT (editor), "char-added",
 						  G_CALLBACK (on_char_added),
 						  sdb_plugin);
@@ -380,7 +380,7 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 
 static void
 on_editor_foreach_disconnect (gpointer key, gpointer value, gpointer user_data)
-{
+{	
 	g_signal_handlers_disconnect_by_func (G_OBJECT(key),
 										  G_CALLBACK (on_editor_saved),
 										  user_data);
@@ -407,7 +407,7 @@ goto_file_line (AnjutaPlugin *plugin, const gchar *filename, gint lineno)
 	loader = anjuta_shell_get_interface (plugin->shell, IAnjutaFileLoader,
 										 NULL);
 		
-	uri = g_strdup_printf ("file:///%s#%d", filename, lineno);
+	uri = g_strdup_printf ("file://%s#%d", filename, lineno);
 	ianjuta_file_loader_load (loader, uri, FALSE, NULL);
 	g_free (uri);
 }
@@ -541,20 +541,16 @@ on_global_treeview_row_expanded (GtkTreeView *tree_view,
 }
 
 static void
-on_editor_foreach_clear (gpointer key, gpointer value, gpointer user_data)
+on_global_treeview_row_collapsed (GtkTreeView *tree_view,
+									GtkTreeIter *iter,
+                                    GtkTreePath *path,
+                                    SymbolDBPlugin *user_data)
 {
-	const gchar *uri;
+	DEBUG_PRINT ("on_global_treeview_row_collapsed ()");
+	
+	symbol_db_view_row_collapsed (SYMBOL_DB_VIEW (user_data->dbv_view_tree),
+								user_data->sdbe, iter);
 	
-	uri = (const gchar *)value;
-	if (uri && strlen (uri) > 0)
-	{
-#if 0
-		/* FIXME ?! */
-		DEBUG_PRINT ("Removing file tags of %s", uri);
-		anjuta_symbol_view_workspace_remove_file (ANJUTA_SYMBOL_VIEW (sv_plugin->sv_tree),
-											   uri);
-#endif
-	}
 }
 
 static void
@@ -563,17 +559,15 @@ value_removed_current_editor (AnjutaPlugin *plugin,
 {
 	SymbolDBPlugin *sdb_plugin;
 
+	if (!IANJUTA_IS_EDITOR (data))
+		return;
+	
+	DEBUG_PRINT ("value_removed_current_editor ()");
 	/* let's remove the timeout for symbols refresh */
 	g_source_remove (timeout_id);
 	need_symbols_update = FALSE;
 	
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
-/* FIXME 	
-	ui = anjuta_shell_get_ui (plugin->shell, NULL);
-	action = anjuta_ui_get_action (ui, "ActionGroupSymbolNavigation",
-								   "ActionGotoSymbol");
-	g_object_set (G_OBJECT (action), "sensitive", FALSE, NULL);
-*/	
 	sdb_plugin->current_editor = NULL;
 }
 
@@ -661,7 +655,7 @@ on_project_element_removed (IAnjutaProjectManager *pm, const gchar *uri,
 	}
 }
 
-static void 
+static void
 sources_array_free (gpointer data)
 {
 	GPtrArray* sources = (GPtrArray*) data;
@@ -669,6 +663,72 @@ sources_array_free (gpointer data)
 	g_ptr_array_free (sources, TRUE);
 }
 
+static void
+on_single_file_scan_end (SymbolDBEngine *dbe, gpointer data)
+{	
+	AnjutaPlugin *plugin;
+	AnjutaStatus *status;	
+	SymbolDBPlugin *sdb_plugin;
+	gchar *message;
+	
+	plugin = ANJUTA_PLUGIN (data);
+	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
+		
+	status = anjuta_shell_get_status (plugin->shell, NULL);
+	
+	if (status == NULL)
+		return;
+	
+	sdb_plugin->files_count_done++;	
+	message = g_strdup_printf ("%d files scanned out of %d", 
+							   sdb_plugin->files_count_done, sdb_plugin->files_count);
+	
+	DEBUG_PRINT ("on_single_file_scan_end (): %d out of %d", sdb_plugin->files_count_done, 
+				 sdb_plugin->files_count);	
+
+	anjuta_status_progress_tick (status, NULL, message);
+	g_free (message);
+}
+
+static void
+on_importing_project_end (SymbolDBEngine *dbe, gpointer data)
+{
+	SymbolDBPlugin *sdb_plugin;
+	AnjutaStatus *status;
+	
+	g_return_if_fail (data != NULL);
+	
+	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (data);
+	
+	DEBUG_PRINT ("on_importing_project_end ()");
+
+	status = anjuta_shell_get_status (ANJUTA_PLUGIN (sdb_plugin)->shell, NULL);
+	anjuta_status_progress_reset (status);
+	
+	/* re-enable signals receiving on local-view */
+	symbol_db_view_locals_recv_signals_from_engine (
+						SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals), 
+								 sdb_plugin->sdbe, TRUE);
+
+	/* and on global view */
+	symbol_db_view_recv_signals_from_engine (SYMBOL_DB_VIEW (sdb_plugin->dbv_view_tree), 
+								 sdb_plugin->sdbe, TRUE);
+	
+	/* re-active global symbols */
+	symbol_db_view_open (SYMBOL_DB_VIEW (sdb_plugin->dbv_view_tree), sdb_plugin->sdbe);
+	
+	/* disconnect this coz it's not important after the process of importing */
+	g_signal_handlers_disconnect_by_func (dbe, on_single_file_scan_end, data);																 
+	
+	/* disconnect it as we don't need it anymore. */
+	g_signal_handlers_disconnect_by_func (dbe, on_importing_project_end, data);
+	
+	sdb_plugin->files_count_done = 0;
+	sdb_plugin->files_count = 0;
+}
+
+
+
 /* add a new project */
 static void
 project_root_added (AnjutaPlugin *plugin, const gchar *name,
@@ -696,8 +756,10 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 			gboolean needs_sources_scan = FALSE;
 			gboolean project_exist = FALSE;
 			gint i;
-			GHashTable* lang_hash = 
-				g_hash_table_new_full (g_str_hash, g_str_equal, NULL, sources_array_free);
+			GHashTable* lang_hash; 
+				
+			lang_hash = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, 
+											  sources_array_free);
 			
 			status = anjuta_shell_get_status (plugin->shell, NULL);
 			anjuta_status_progress_add_ticks (status, 1);
@@ -734,14 +796,31 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 				g_error ("Symbol-DB: error in opening project");
 			}
 
+			/* needs an import */
 			if (needs_sources_scan == TRUE)
 			{
 				GList* prj_elements_list;
 				GPtrArray* sources_array = NULL;
 				GPtrArray* languages_array = NULL;
 				GHashTable *check_unique_file;
-				IAnjutaLanguage* lang_manager =
-						anjuta_shell_get_interface (plugin->shell, IAnjutaLanguage, 
+				IAnjutaLanguage* lang_manager;
+				
+				/* if we're importing first shut off the signal receiving.
+				 * We'll re-enable that on scan-end 
+				 */
+				symbol_db_view_locals_recv_signals_from_engine (																
+							SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals), 
+											 sdb_plugin->sdbe, FALSE);
+
+				symbol_db_view_recv_signals_from_engine (																
+							SYMBOL_DB_VIEW (sdb_plugin->dbv_view_tree), 
+											 sdb_plugin->sdbe, FALSE);
+				
+				g_signal_connect (G_OBJECT (sdb_plugin->sdbe), "scan-end",
+					  G_CALLBACK (on_importing_project_end), plugin);
+				
+				
+				lang_manager =	anjuta_shell_get_interface (plugin->shell, IAnjutaLanguage, 
 													NULL);
 			
 				if (!lang_manager)
@@ -817,18 +896,25 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 					{
 						sources_array = g_ptr_array_new ();
 					}	
-
+					
 					if (!languages_array)
 					{
 						languages_array = g_ptr_array_new ();
 					}
-					
+
+					sdb_plugin->files_count++;
 					g_ptr_array_add (sources_array, local_filename);
 					g_ptr_array_add (languages_array, g_strdup (lang));					
 				}
 			
 				DEBUG_PRINT ("calling symbol_db_engine_add_new_files  with root_dir %s",
 							 root_dir);
+
+				/* connect to receive signals on single file scan complete. We'll
+				 * update a status bar notifying the user about the status
+				 */
+				g_signal_connect (G_OBJECT (sdb_plugin->sdbe), "single-file-scan-end",
+					  G_CALLBACK (on_single_file_scan_end), plugin);
 				
 				symbol_db_engine_add_new_files (sdb_plugin->sdbe, root_dir,
 									sources_array, languages_array, TRUE);
@@ -842,9 +928,13 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 				g_ptr_array_foreach (languages_array, (GFunc)g_free, NULL);
 				g_ptr_array_free (languages_array, TRUE);
 			}
+			else	/* no import needed. Update the symbols */
+			{
+				symbol_db_engine_update_project_symbols (sdb_plugin->sdbe, root_dir);
+			}
+			anjuta_status_progress_tick (status, NULL, _("Populating symbols' db..."));
+			anjuta_status_progress_add_ticks (status, sdb_plugin->files_count);
 			
-			anjuta_status_progress_tick (status, NULL, _("Created symbols..."));
-
 			symbol_db_view_open (SYMBOL_DB_VIEW (sdb_plugin->dbv_view_tree),
 								 sdb_plugin->sdbe);
 
@@ -869,7 +959,7 @@ project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 	SymbolDBPlugin *sdb_plugin;
 	
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
-	
+	DEBUG_PRINT ("project_root_removed ()");
 	/* Disconnect events from project manager */
 	
 	/* FIXME: There should be a way to ensure that this project manager
@@ -884,6 +974,13 @@ project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 										  on_project_element_removed,
 										  sdb_plugin);
 
+	/* clear locals symbols and the associated cache*/
+	symbol_db_view_locals_clear_cache (SYMBOL_DB_VIEW_LOCALS (
+											sdb_plugin->dbv_view_tree_locals));
+	
+	/* clear global symbols */
+	symbol_db_view_clear_cache (SYMBOL_DB_VIEW (sdb_plugin->dbv_view_tree));
+	
 	/* don't forget to close the project */
 	symbol_db_engine_close_project (sdb_plugin->sdbe, 
 									sdb_plugin->project_root_dir);
@@ -894,32 +991,6 @@ project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 	sdb_plugin->project_root_dir = NULL;
 }
 
-static void
-on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
-				 AnjutaSession *session, SymbolDBPlugin *plugin)
-{
-	GList *files;
-	gint i;			
-	DEBUG_PRINT ("on_session_load ()");
-	
-	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
-		return;
-	
-	files = anjuta_session_get_string_list (session, "File Loader", "Files");
-
-	for (i=0; i < g_list_length (files); i++)
-	{
-		gchar * node = g_list_nth_data (files, i);
-		DEBUG_PRINT ("file %s", node);
-	}
-	
-
-	
-	g_list_foreach (files, (GFunc)g_free, NULL);
-	g_list_free (files);
-	
-}
-
 static gboolean
 symbol_db_activate (AnjutaPlugin *plugin)
 {
@@ -932,13 +1003,6 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	symbol_db = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
 	symbol_db->ui = anjuta_shell_get_ui (plugin->shell, NULL);
 
-	/* connect for session load event 
-	g_signal_connect (plugin->shell, "load-session",
-					  G_CALLBACK (on_session_load),
-					  plugin);
-	*/
-	
-	
 	/* create SymbolDBEngine */
 	symbol_db->sdbe = symbol_db_engine_new ();
 	
@@ -955,6 +1019,10 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	
 	symbol_db->dbv_view_locals_tab_label = gtk_label_new (_("Local" ));
 	symbol_db->dbv_view_tree_locals = symbol_db_view_locals_new ();
+	/* activate signals receiving by default */
+	symbol_db_view_locals_recv_signals_from_engine (
+					SYMBOL_DB_VIEW_LOCALS (symbol_db->dbv_view_tree_locals), 
+											 symbol_db->sdbe, TRUE);										 
 
 	g_object_add_weak_pointer (G_OBJECT (symbol_db->dbv_view_tree_locals),
 							   (gpointer)&symbol_db->dbv_view_tree_locals);
@@ -978,12 +1046,19 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	symbol_db->dbv_view_tree = symbol_db_view_new ();
 	g_object_add_weak_pointer (G_OBJECT (symbol_db->dbv_view_tree),
 							   (gpointer)&symbol_db->dbv_view_tree);
+	/* activate signals receiving by default */
+	symbol_db_view_recv_signals_from_engine (
+					SYMBOL_DB_VIEW (symbol_db->dbv_view_tree), 
+											 symbol_db->sdbe, TRUE);										 
 
 	g_signal_connect (G_OBJECT (symbol_db->dbv_view_tree), "row-activated",
 					  G_CALLBACK (on_global_treeview_row_activated), plugin);
 
 	g_signal_connect (G_OBJECT (symbol_db->dbv_view_tree), "row-expanded",
 					  G_CALLBACK (on_global_treeview_row_expanded), plugin);
+
+	g_signal_connect (G_OBJECT (symbol_db->dbv_view_tree), "row-collapsed",
+					  G_CALLBACK (on_global_treeview_row_collapsed), plugin);	
 	
 	gtk_container_add (GTK_CONTAINER(symbol_db->scrolled_global), 
 					   symbol_db->dbv_view_tree);
@@ -1022,11 +1097,6 @@ symbol_db_activate (AnjutaPlugin *plugin)
 		anjuta_plugin_add_watch (plugin, "document_manager_current_editor",
 								 value_added_current_editor,
 								 value_removed_current_editor, NULL);
-#if 0
-	/* Add UI */
-	symbol_db->merge_id = 
-		anjuta_ui_merge (symbol_db->ui, UI_FILE);
-#endif	
 	/* Added widgets */
 	anjuta_shell_add_widget (plugin->shell, symbol_db->dbv_notebook,
 							 "AnjutaSymbolBrowser", _("Symbols"),
@@ -1065,24 +1135,11 @@ symbol_db_deactivate (AnjutaPlugin *plugin)
 									  on_treesearch_symbol_selected_event,
 									  plugin);
 	
-/*	
-	DEBUG_PRINT ("SymbolDBPlugin: destroying locals view ...");
-	g_object_unref (sdb_plugin->dbv_view_tree_locals);
-		
-	DEBUG_PRINT ("SymbolDBPlugin: destroying globals view ...");
-	g_object_unref (sdb_plugin->dbv_view_tree);
-	
-	DEBUG_PRINT ("SymbolDBPlugin: destroying search ...");
-	g_object_unref (sdb_plugin->dbv_view_tree_search);
-*/	
-	
 	/* Ensure all editor cached info are released */
 	if (sdb_plugin->editor_connected)
 	{
 		g_hash_table_foreach (sdb_plugin->editor_connected,
 							  on_editor_foreach_disconnect, plugin);
-		g_hash_table_foreach (sdb_plugin->editor_connected,
-							  on_editor_foreach_clear, plugin);
 		g_hash_table_destroy (sdb_plugin->editor_connected);
 		sdb_plugin->editor_connected = NULL;
 	}
@@ -1094,19 +1151,6 @@ symbol_db_deactivate (AnjutaPlugin *plugin)
 	/* Remove widgets: Widgets will be destroyed when dbv_notebook is removed */
 	anjuta_shell_remove_widget (plugin->shell, sdb_plugin->dbv_notebook, NULL);
 
-#if 0			
-	/* Remove UI */
-	anjuta_ui_unmerge (sdb_plugin->ui, sdb_plugin->merge_id);
-
-	/* Remove action group */
-	anjuta_ui_remove_action_group (sv_plugin->ui, sv_plugin->action_group);
-	anjuta_ui_remove_action_group (sv_plugin->ui, sv_plugin->popup_action_group);
-	anjuta_ui_remove_action_group (sdb_plugin->ui, sdb_plugin->action_group_nav);	
-	ui = anjuta_shell_get_ui (plugin->shell, NULL);
-/*	anjuta_ui_remove_action_group (ui, ((SymbolDBPlugin*)plugin)->action_group); */
-	anjuta_ui_unmerge (ui, ((SymbolDBPlugin*)plugin)->uiid);
-#endif			
-	
 	sdb_plugin->root_watch_id = 0;
 	sdb_plugin->editor_watch_id = 0;
 	sdb_plugin->dbv_notebook = NULL;
@@ -1124,6 +1168,7 @@ symbol_db_deactivate (AnjutaPlugin *plugin)
 static void
 symbol_db_finalize (GObject *obj)
 {
+	DEBUG_PRINT ("Symbol-DB finalize");
 	/* Finalization codes here */
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
 }
@@ -1140,8 +1185,8 @@ symbol_db_instance_init (GObject *obj)
 {
 	SymbolDBPlugin *plugin = (SymbolDBPlugin*)obj;
 
-	plugin->uiid = 0;
-	plugin->widget = NULL;
+	plugin->files_count_done = 0;
+	plugin->files_count = 0;
 }
 
 static void
@@ -1172,13 +1217,11 @@ isymbol_manager_search (IAnjutaSymbolManager *sm,
 
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
 	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe);
-
 	
 	if (match_name && strlen (match_name) > 0)
 		name = match_name;
 	else
 		name = NULL;
-
 	
 	iterator = 
 		symbol_db_engine_find_symbol_by_name_pattern (dbe, 
@@ -1214,17 +1257,8 @@ isymbol_manager_get_parents (IAnjutaSymbolManager *sm,
 							 const gchar *symbol_name,
 							 GError **err)
 {
-#if 0
-	const GPtrArray *tags_array;
-	AnjutaSymbolIter *iter = NULL;
-	
-	tags_array = tm_workspace_get_parents (symbol_name);
-	if (tags_array)
-	{
-		iter = anjuta_symbol_iter_new (tags_array);
-		return IANJUTA_ITERABLE (iter);
-	}
-#endif	
+	/* TODO */
+	DEBUG_PRINT ("TODO: isymbol_manager_get_parents ()");
 	return NULL;
 }
 
